@@ -1,15 +1,17 @@
+import logging
 import os
 import shutil
 from typing import List, Any
 
 import click
+from plumbum import local
 
 from alfred.decorator import AlfredCommand, ALFRED_COMMANDS
 from alfred.main import lookup_alfred_configuration
+from alfred.logger import logger
 from alfred.lib import import_python, list_python_modules, ROOT_DIR, InvalidPythonModule, print_error
 from alfred.type import Environment
 
-
 @click.command('init')
 def init():
     if os.path.isfile('.alfred.yml'):
@@ -45,7 +47,7 @@ class AlfredCli(click.MultiCommand):
             if click_command.name == cmd_name:
                 alfred_configuration = lookup_alfred_configuration()
                 for environment in alfred_configuration.environments():
-                    os.environ[environment.key] = environment.value
+                    local.env[environment.key] = environment.value
 
                 return click_command
 
@@ -84,7 +86,13 @@ class AlfredCli(click.MultiCommand):
         return alfred_configuration.plugins()
 
 
-cli = AlfredCli(help='alfred is a building tool to make engineering tasks easier to develop and to maintain')
+@click.command(cls=AlfredCli,
+               help='alfred is a building tool to make engineering tasks easier to develop and to maintain')
+@click.option("-d", "--debug", is_flag=True, help="display debug information like command runned and working directory")
+def cli(debug: bool):
+    if debug:
+        logger.setLevel(logging.DEBUG)
+
 
 if __name__ == '__main__':
-    cli()
+    cli()  # pylint: disable=no-value-for-parameter
